@@ -87,6 +87,18 @@ N_("[image:4]Cut the red pepper in thin slices.")
 N_("[image:0]Mix fruits and vegetables in a bowl.")
 N_("[image:5]Add lime as you please.")
 N_("[image:6]Enjoy!")
+N_("Sylvia's Bratkartoffeln")
+N_("Meatless version of a German classic.")
+N_("Suitable for oven cooking.")
+N_("Peel and chop potatoes to fry, preferably in thick chips.")
+N_("Peel and chop the onions.")
+N_("Prepare the cheese  (if it's not already).")
+N_("Heat abundant oil and when is ready, carefully add the potatoes.")
+N_("Once potatoes are half made, add the onions, and when everything is ready add the cheese.")
+N_("** Alternatively, you can add the cheese at the moment of serving it.")
+N_("** If you're using tofu, prepare the tofu first and add it at the moment of serving.")
+N_("You can make it vegan, switching the cheese for vegan cheese or tofu.")
+N_("You can use prepared cheese (like grated or shredded), but it tastes better if you use the fresh one and prepare it yourself.")
 N_("Mantovana Cake")
 N_("Mantovana cake (or Torta Mantovana in Italian) is a Tuscan classic. It is simple, yet rich and delicious. Very good for breakfast - Italian style - or as snacks, accompanied with coffee or tea. A small note; the vanilla baking powder is typical in Italy for baked sweet goods, and negates the need to add vanilla extract separately to a recipe. You are fine just using regular baking powder, but remember to add 1/2 teaspoon of vanilla extract. If you can't get hold of the vanilla powdered sugar for dusting, just use the regular powdered sugar.")
 N_("[image:0]Preheat oven to [temperature:180C]. Line a 9-inch round cake pan with parchment paper and grease well.")
@@ -97,6 +109,20 @@ N_("[image:0]Pour the batter into a 9-inch round baking pan. Sprinkle the almond
 N_("[timer:00:25:00,Bake]Bake for 25-30 minutes or until a cake tester inserted into the center cake comes out clean. The cake should have a nice golden colour.")
 N_("[image:0]Let rest in the pan for 10 minutes, then invert onto a cooling rack to cool completely.")
 N_("[image:0]Before serving, dust the top generously with vanilla powdered sugar.")
+N_("Nasi Lemak (Coconut Rice)")
+N_("This is a truly Malaysian dish, very typically eaten for breakfast. It is a delightful combination of boiled rice, coconut milk and pandan (screwpine leaves), eaten with the sambal (hot sauce), and accompaniments such as sliced cucumbers, hard-boiled eggs, fried dried anchovies and fried groundnuts.")
+N_("See my recipe for Sambal Ikan Bilis (Hot Sauce with Anchovies) to complete this dish.")
+N_("In this recipe, I outlined the steps to cook the rice on a stove. If you have a rice cooker, then you'll only have two steps; 1) Combine all ingredients in the pot of the rice cooker, and 2) Hit the \"cook\" button.")
+N_("Prepare the rice; rinse, soak for 30 minutes, and drain. You can also use any long-grain rice instead of basmati.")
+N_("[image:0]Peel the shallots, garlic and ginger, then slice them thinly.")
+N_("[image:1]Mix the coconut milk, water, shallots, garlic and ginger in a medium-sized pot. Tie the pandan leaves in a knot, and add it to the mixture. If you can't get a hold of pandan, use one stalk of lemongrass as a substitute. Peel the tough outer leaves, slice off the lower bulb and the upper end of the stalk that is green and woody. Crush the lower bulby end, and throw it into the mixture. Season the mixture with salt. It should taste salty enough, and a bit more.")
+N_("Bring the mixture to a boil.")
+N_("When the mixture has come to a boil, stir in the salt and fenugreek seeds (if using), and bring it back to a gentle simmer.")
+N_("Cover the pot and turn the heat down to low. Don't take off the lid while the rice is cooking.")
+N_("Start checking the rice at around 20 minutes. When done, the rice will be firm but tender, and no longer crunchy.")
+N_("Turn off the heat and let stand about 5-7 minutes, covered.")
+N_("Remove the lid, and fluff up the rice with a fork. Let it stand for a few more minutes to dry out the steam.")
+N_("[image:2]Serve with sambal ikan bilis (hot sauce with anchovies), sunny-side up or hard-boiled egg, sliced cucumbers.")
 N_("Non-knead buns")
 N_("Very quick fresh bread for breakfast with 5 minutes of work.")
 N_("[image:1]Preparation: Mix together all of the ingredients in a large bowl into a thick porridge-like dough. Do not knead the dough, just mix it together. ")
@@ -206,6 +232,18 @@ N_("[image:6]Add the rice and break the chunk of rice so the rice fry out and mi
 N_("[image:7]Add the fish and toss the rice again.")
 N_("Add the fish sauce to taste. Fish sauce has a strong smell; if you don't fancy it, you can substitute it with soy sauce. Mix well to incorporate all the flavours.")
 N_("[image:8]Serve immediately with sunny-side up eggs, and garnish with spring onions.")
+N_("Sambal Ikan Bilis (Hot Sauce with Dried Anchovies)")
+N_("The sambal (hot sauce) is an essential component of nasi lemak. For this sambal, dried anchovies (ikan bilis) are used. These little salted fish can be found in Asian specialty supermarkets.")
+N_("[image:0]Prep the dried chillies; remove the stalks, cut in 1-inch pieces and remove the seeds. Rinse, then soak in hot water to soften.")
+N_("[image:1]Prep the dried anchovies; rinse, and soak in hot water to soften. Then drain and pat dry.")
+N_("Peel the shallots, ginger and garlic. Put them in a blender together with the prepped dried chillies. Add 1 cup of water. Blend to a puree.")
+N_("[image:2]Heat 1/4 cup of coconut oil in a pan and stir-fry the chilli-spice puree until the oil separates, about 20 minutes.")
+N_("[image:3]Pan-fry the dried anchovies in a separate small pan/skillet - using enough oil to cover bottom of pan - until light golden brown. Set aside.")
+N_("Take the large onion, quarter it and slice across. Add these onions and the fried anchovies into the chilli-spice mixture and cook until the onion is transparent.")
+N_("Add the coconut milk, tamarind paste and remaining 1 cup water, and bring to a boil on medium heat.")
+N_("[image:4]Turn the heat down to low. Season with sugar and salt. The sambal must have a hint of sweetness.")
+N_("[image:5]Let the sambal simmer uncovered until oil appears on the surface. Stir every 15 minutes. This will take about an hour. The sambal will turn into a deep red shade.")
+N_("[image:6]Serve with nasi lemak (coconut rice).")
 N_("Savoury cakes")
 N_("These savory cakes can be served as appetizers or as main course. There are several variations that you can bake with the same base depending on your mood and tastes. Quite common at French parties.")
 N_("Prepare the batter: melt butter in a large bowl, then mix with the eggs, flour and yeast in a bowl.")
