@@ -27,6 +27,10 @@
 #include "gr-about-dialog.h"
 #include "gr-utils.h"
 
+#ifdef GDK_WINDOWING_QUARTZ
+#include <sys/sysctl.h>
+#endif
+
 struct _GrAboutDialog
 {
         GtkAboutDialog parent_instance;
@@ -155,6 +159,7 @@ add_built_logo (GrAboutDialog *about)
         g_object_unref (copyright_label);
 }
 
+#ifndef GDK_WINDOWING_QUARTZ
 static char *
 find_string_between (const char *buffer,
                      const char *before,
@@ -173,6 +178,7 @@ find_string_between (const char *buffer,
 
         return NULL;
 }
+#endif
 
 static void
 get_os_information (char **os_name,
@@ -180,23 +186,33 @@ get_os_information (char **os_name,
                     char **desktop,
                     char **version)
 {
-        g_autofree char *buffer;
-        g_autofree char *buffer2;
-        const char *value;
-
         *os_name = NULL;
         *os_type = NULL;
         *desktop = NULL;
         *version = NULL;
 
-        if (g_file_get_contents ("/etc/os-release", &buffer, NULL, NULL))
-                *os_name = find_string_between (buffer, "PRETTY_NAME=\"", "\"");
-
         if (GLIB_SIZEOF_VOID_P == 8)
                 *os_type = g_strdup ("64-bit");
         else
                 *os_type = g_strdup ("32-bit");
 
+#ifdef GDK_WINDOWING_QUARTZ
+	{
+	char str[256];
+	size_t size = sizeof(str);
+
+	sysctlbyname ("kern.osrelease", str, &size, NULL, 0);
+	*os_name = g_strdup_printf ("OS X %s", str);
+	}
+#else
+	{
+        g_autofree char *buffer;
+        g_autofree char *buffer2;
+        const char *value;
+
+        if (g_file_get_contents ("/etc/os-release", &buffer, NULL, NULL))
+                *os_name = find_string_between (buffer, "PRETTY_NAME=\"", "\"");
+
         value = g_getenv ("XDG_CURRENT_DESKTOP");
         if (value) {
                 g_auto(GStrv) strv = g_strsplit (value, ":", 0);
@@ -215,13 +231,11 @@ get_os_information (char **os_name,
                 if (platform && minor && micro)
                         *version = g_strconcat (platform, ".", minor, ".", micro, NULL);
         }
+	}
+#endif
 
         if (!*os_name)
                 *os_name = g_strdup (_("Unknown"));
-        if (!*os_type)
-                *os_type = g_strdup (_("Unknown"));
-        if (!*desktop)
-                *desktop = g_strdup (_("Unknown"));
 }
 
 static void
@@ -333,6 +347,8 @@ text_buffer_append (GtkTextBuffer *buffer,
         gtk_text_buffer_insert (buffer, &iter, text, -1);
 }
 
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wformat-nonliteral"
 static void
 text_buffer_append_printf (GtkTextBuffer *buffer,
                            const char    *format,
@@ -343,15 +359,14 @@ text_buffer_append_printf (GtkTextBuffer *buffer,
         int len;
 
         va_start (args, format);
-
         len = g_vasprintf (&buf, format, args);
         if (len >= 0) {
                 text_buffer_append (buffer, buf);
                 g_free (buf);
         }
-
         va_end (args);
 }
+#pragma GCC diagnostic pop
 
 static void
 text_buffer_append_link (GtkTextView *view,
@@ -467,10 +482,12 @@ populate_system_tab (GtkTextView *view)
                 text_buffer_append (buffer, "\n");
 
                 text_buffer_append_printf (buffer, "\t%s\t%s\n", C_("OS metadata", "Name"), os_name);
-                text_buffer_append_printf (buffer, "\t%s\t%s\n", C_("OS metadata", "Type"), os_type);
-                if (version)
+		if (os_type)
+                	text_buffer_append_printf (buffer, "\t%s\t%s\n", C_("OS metadata", "Type"), os_type);
+
+                if (desktop && version)
                         text_buffer_append_printf (buffer, "\t%s\t%s %s\n", C_("OS metadata", "Desktop"), desktop, version);
-                else
+                else if (desktop)
                         text_buffer_append_printf (buffer, "\t%s\t%s\n", C_("OS metadata", "Desktop"), desktop);
 
                 text_buffer_append (buffer, "\n");
@@ -650,6 +667,61 @@ text_view_motion_notify_event (GtkWidget      *text_view,
         return FALSE;
 }
 
+static void
+toggle_system (GtkToggleButton *button,
+               gpointer         user_data)
+{
+        GtkAboutDialog *about = user_data;
+        GtkWidget *credits_button;
+        GtkWidget *stack;
+        gboolean show_system;
+        guint signal_id;
+
+        if (GPOINTER_TO_INT (g_object_get_data (G_OBJECT (about), "in_page_changed")))
+                return;
+
+        stack = GTK_WIDGET (g_object_get_data (G_OBJECT (about), "stack"));
+        credits_button = GTK_WIDGET (g_object_get_data (G_OBJECT (about), "credits_button"));
+
+        signal_id = g_signal_lookup ("toggled", GTK_TYPE_TOGGLE_BUTTON);
+        g_signal_handlers_block_matched (credits_button,
+                                         G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_DATA,
+                                         signal_id, 0, NULL, NULL, about);
+
+        show_system = gtk_toggle_button_get_active (button);
+        gtk_stack_set_visible_child_name (GTK_STACK (stack), show_system ? "system" : "main");
+
+        g_signal_handlers_unblock_matched (credits_button,
+                                           G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_DATA,
+                                           signal_id, 0, NULL, NULL, about);
+}
+
+static void
+page_changed (GObject *stack, GParamSpec *pspec, gpointer user_data)
+{
+        GtkAboutDialog *about = user_data;
+        GtkWidget *credits_button;
+        GtkWidget *system_button;
+        const char *visible;
+
+        if (GPOINTER_TO_INT (g_object_get_data (G_OBJECT (about), "in_page_changed")))
+                return;
+
+        g_object_set_data (G_OBJECT (about), "in_page_changed", GINT_TO_POINTER (TRUE));
+
+        credits_button = GTK_WIDGET (g_object_get_data (G_OBJECT (about), "credits_button"));
+        system_button = GTK_WIDGET (g_object_get_data (G_OBJECT (about), "system_button"));
+
+        visible = gtk_stack_get_visible_child_name (GTK_STACK (stack));
+
+        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (credits_button),
+                                      strcmp (visible, "credits") == 0);
+        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (system_button),
+                                      strcmp (visible, "system") == 0);
+
+        g_object_set_data (G_OBJECT (about), "in_page_changed", GINT_TO_POINTER (FALSE));
+}
+
 static void
 add_system_tab (GrAboutDialog *about)
 {
@@ -659,6 +731,7 @@ add_system_tab (GrAboutDialog *about)
         GtkWidget *sw;
         GtkWidget *view;
         GdkCursor *cursor;
+        gboolean use_header_bar;
 
         content = gtk_dialog_get_content_area (GTK_DIALOG (about));
         box = find_child_with_name (content, "box");
@@ -693,6 +766,43 @@ add_system_tab (GrAboutDialog *about)
         gtk_stack_add_titled (GTK_STACK (stack), sw, "system", _("System"));
 
         populate_system_tab (GTK_TEXT_VIEW (view));
+
+        g_object_get (about, "use-header-bar", &use_header_bar, NULL);
+        if (!use_header_bar) {
+                GtkWidget *button;
+                GtkWidget *action_area;
+                GList *children, *l;
+
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+                action_area = gtk_dialog_get_action_area (GTK_DIALOG (about));
+G_GNUC_END_IGNORE_DEPRECATIONS
+                children = gtk_container_get_children (GTK_CONTAINER (action_area));
+                for (l = children; l; l = l->next) {
+                        GtkWidget *child = l->data;
+                        gboolean secondary;
+
+                        gtk_container_child_get (GTK_CONTAINER (action_area), child, "secondary", &secondary, NULL);
+
+                        if (gtk_widget_get_visible (child) && secondary) {
+                                g_object_set_data (G_OBJECT (about), "credits_button", child);
+                                break;
+                        }
+                }
+                g_list_free (children);
+
+                button = gtk_toggle_button_new_with_label (_("System"));
+                gtk_widget_show (button);
+                gtk_dialog_add_action_widget (GTK_DIALOG (about), button, GTK_RESPONSE_NONE);
+                gtk_container_child_set (GTK_CONTAINER (gtk_widget_get_parent (button)),
+                                         button,
+                                         "secondary", TRUE,
+                                         NULL);
+                g_object_set_data (G_OBJECT (about), "stack", stack);
+                g_object_set_data (G_OBJECT (about), "system_button", button);
+
+                g_signal_connect (button, "toggled", G_CALLBACK (toggle_system), about);
+                g_signal_connect (stack, "notify::visible-child-name", G_CALLBACK (page_changed), about);
+        }
 }
 
 GrAboutDialog *
@@ -708,6 +818,8 @@ gr_about_dialog_new (void)
                 "Mohammed Sadiq",
                 "Sam Hewitt",
                 "Nirbheek Chauhan",
+                "Ekta Nandwani",
+                "Maithili Bhide",
                 NULL
         };
         const char *recipe_authors[] = {
