@@ -322,9 +322,9 @@ setup_step (GrCookingView *view)
                 gtk_widget_set_halign (view->text_box, GTK_ALIGN_START);
                 ri = &g_array_index (view->images, GrImage, s->image);
                 if (view->wide)
-                        pixbuf = load_pixbuf_fill_size (ri->path, 0, 640, 480);
+                        pixbuf = load_pixbuf_fill_size (ri->path, 640, 480);
                 else
-                        pixbuf = load_pixbuf_fill_size (ri->path, 0, 320, 240);
+                        pixbuf = load_pixbuf_fill_size (ri->path, 320, 240);
                 gtk_image_set_from_pixbuf (GTK_IMAGE (view->cooking_image), pixbuf);
                 gtk_stack_set_visible_child_name (GTK_STACK (view->cooking_stack), "image");
         }
@@ -404,7 +404,7 @@ show_system_notification (GrTimer   *timer,
 
         notification = g_notification_new (_("Timer is up!"));
 
-        body = g_strdup_printf (_("The timer for “%s” has expired."), gr_timer_get_name (timer));
+        body = g_strdup_printf (_("Timer for “%s” has expired."), gr_timer_get_name (timer));
         g_notification_set_body (notification, body);
 
         g_notification_set_default_action_and_target (notification, "app.timer-expired",
