@@ -54,6 +54,7 @@ struct _GrRecipeExporter
         GList *sources;
         char *dir;
 
+        gboolean just_export;
         gboolean contribute;
 
         GtkWidget *dialog_heading;
@@ -77,12 +78,22 @@ gr_recipe_exporter_finalize (GObject *object)
         G_OBJECT_CLASS (gr_recipe_exporter_parent_class)->finalize (object);
 }
 
+static guint done_signal;
+
 static void
 gr_recipe_exporter_class_init (GrRecipeExporterClass *klass)
 {
         GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
         object_class->finalize = gr_recipe_exporter_finalize;
+
+        done_signal = g_signal_new ("done",
+                                    G_TYPE_FROM_CLASS (klass),
+                                    G_SIGNAL_RUN_LAST,
+                                    0,
+                                    NULL, NULL,
+                                    NULL,
+                                    G_TYPE_NONE, 1, G_TYPE_FILE);
 }
 
 static void
@@ -119,17 +130,69 @@ cleanup_export (GrRecipeExporter *exporter)
 }
 
 #ifdef ENABLE_AUTOAR
+
+static void
+file_chooser_response (GtkNativeDialog  *self,
+                       int               response_id,
+                       GrRecipeExporter *exporter)
+{
+        if (response_id == GTK_RESPONSE_ACCEPT) {
+                g_autoptr(GFile) file = NULL;
+
+                file = gtk_file_chooser_get_file (GTK_FILE_CHOOSER (self));
+                g_file_copy_async (exporter->dest, file, 0, 0, NULL, NULL, NULL, NULL, NULL);
+        }
+
+        gtk_native_dialog_destroy (self);
+
+        cleanup_export (exporter);
+}
+
+static void
+mail_done (GObject      *source,
+           GAsyncResult *result,
+           gpointer      data)
+{
+        GrRecipeExporter *exporter = data;
+        g_autoptr(GError) error = NULL;
+
+        if (!gr_send_mail_finish (result, &error)) {
+                GObject *file_chooser;
+
+                g_message ("Sending mail failed: %s", error->message);
+
+                file_chooser = (GObject *)gtk_file_chooser_native_new (_("Save the exported recipe"),
+                                                                       GTK_WINDOW (exporter->window),
+                                                                       GTK_FILE_CHOOSER_ACTION_SAVE,
+                                                                       _("Save"),
+                                                                       _("Cancel"));
+                gtk_native_dialog_set_modal (GTK_NATIVE_DIALOG (file_chooser), TRUE);
+
+                g_signal_connect (file_chooser, "response", G_CALLBACK (file_chooser_response), exporter);
+
+                gtk_native_dialog_show (GTK_NATIVE_DIALOG (file_chooser));
+                return;
+        }
+
+        cleanup_export (exporter);
+}
+
 static void
 completed_cb (AutoarCompressor *compressor,
               GrRecipeExporter *exporter)
 {
         g_autofree char *path = NULL;
-        g_autoptr(GError) error = NULL;
         const char *address;
         const char *subject;
         g_autofree char *body = NULL;
         const char *attachments[2];
 
+        if (exporter->just_export) {
+                g_signal_emit (exporter, done_signal, 0, exporter->output);
+                cleanup_export (exporter);
+                return;
+        }
+
         if (exporter->contribute) {
                 address = "recipes-list@gnome.org";
                 subject = _("Recipe contribution");
@@ -151,7 +214,7 @@ completed_cb (AutoarCompressor *compressor,
                         g_string_append (s, _("Hi,\n\nyou should try these recipes."));
                 }
                 g_string_append (s, "\n\n");
-                g_string_append (s, _("(The attached file can be imported into GNOME recipes.)"));
+                g_string_append (s, _("(The attached file can be imported into GNOME Recipes.)"));
 
                 for (l = exporter->recipes; l; l = l->next) {
                         g_autofree char *formatted = NULL;
@@ -169,9 +232,9 @@ completed_cb (AutoarCompressor *compressor,
         attachments[0] = path;
         attachments[1] = NULL;
 
-        gr_send_mail (GTK_WINDOW (exporter->window), address, subject, body, attachments);
-
-        cleanup_export (exporter);
+        gr_send_mail (GTK_WINDOW (exporter->window),
+                      address, subject, body, attachments,
+                      mail_done, exporter);
 }
 
 static void
@@ -208,7 +271,6 @@ export_one_recipe (GrRecipeExporter  *exporter,
         GrDiets diets;
         GDateTime *ctime;
         GDateTime *mtime;
-        g_autoptr(GrChef) chef = NULL;
         g_autoptr(GArray) images = NULL;
         g_auto(GStrv) paths = NULL;
         int i;
@@ -458,7 +520,7 @@ do_export (GrRecipeExporter *exporter)
 
         for (i = 0; i < 1000; i++) {
                 g_autofree char *tmp;
-                tmp = g_strdup_printf ("%s/.var/app/org.gnome.Recipes/recipes%d.gnome-recipes-export", g_get_home_dir (), i);
+                tmp = g_strdup_printf ("%s/recipes%d.gnome-recipes-export", get_user_data_dir (), i);
                 if (!g_file_test (tmp, G_FILE_TEST_EXISTS)) {
                         path = g_strdup (tmp);
                         break;
@@ -537,7 +599,7 @@ update_contribute_button (GrRecipeExporter *exporter)
         if (readonly) {
                 gtk_widget_set_sensitive (exporter->contribute_button, FALSE);
                 gtk_widget_set_tooltip_text (exporter->contribute_button, _("Some of the selected recipes are included\n"
-                                                                            "with GNOME recipes. You should only contribute\n"
+                                                                            "with GNOME Recipes. You should only contribute\n"
                                                                             "your own recipes."));
                 gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (exporter->friend_button), TRUE);
         }
@@ -641,7 +703,6 @@ show_export_dialog (GrRecipeExporter *exporter)
         g_autoptr(GtkBuilder) builder = NULL;
         GtkWidget *dialog;
         GtkWidget *list;
-        g_autofree char *tmp = NULL;
 
         builder = gtk_builder_new_from_resource ("/org/gnome/Recipes/recipe-export-dialog.ui");
         dialog = GTK_WIDGET (gtk_builder_get_object (builder, "dialog"));
@@ -694,3 +755,38 @@ gr_recipe_exporter_contribute (GrRecipeExporter *exporter,
 
         do_export (exporter);
 }
+
+static void
+collect_all_recipes (GrRecipeExporter *exporter)
+{
+        GrRecipeStore *store;
+        g_autofree char **keys = NULL;
+        guint length;
+        int i;
+
+        store = gr_app_get_recipe_store (GR_APP (g_application_get_default ()));
+        keys = gr_recipe_store_get_recipe_keys (store, &length);
+        for (i = 0; keys[i]; i++) {
+                g_autoptr(GrRecipe) recipe = gr_recipe_store_get_recipe (store, keys[i]);
+                if (!gr_recipe_is_readonly (recipe))
+                        exporter->recipes = g_list_append (exporter->recipes, recipe);
+        }
+}
+
+void
+gr_recipe_exporter_export_all (GrRecipeExporter *exporter,
+                               GFile            *file)
+{
+        collect_all_recipes (exporter);
+
+        g_message ("Exporting %d recipes", g_list_length (exporter->recipes));
+
+        if (exporter->recipes == NULL)
+                return;
+
+        exporter->output = file;
+
+        exporter->just_export = TRUE;
+
+        start_export (exporter);
+}
