@@ -184,7 +184,7 @@ begin_print (GtkPrintOperation *operation,
         g_object_get (printer->recipe, "images", &images, NULL);
         if (images && images->len > 0) {
                 ri = &g_array_index (images, GrImage, 0);
-                printer->image = load_pixbuf_fit_size (ri->path, 0, width / 2, height / 4, FALSE);
+                printer->image = load_pixbuf_fit_size (ri->path, width / 2, height / 4, FALSE);
         }
 
         title_font = pango_font_description_from_string ("Cantarell Bold 18");
