@@ -146,7 +146,16 @@ get_old_user_data_dir (void)
 const char *
 get_pkg_data_dir (void)
 {
-        return PKGDATADIR;
+        static char *dir = NULL;
+
+        if (!dir) {
+                if (g_getenv ("PKG_DATA_DIR"))
+                        dir = (char *)g_getenv ("PKG_DATA_DIR");
+                else
+                        dir = (char *)PKGDATADIR;
+        }
+
+        return (const char *)dir;
 }
 
 void
@@ -434,6 +443,9 @@ portals_available (void)
                 g_autoptr(GDBusConnection) bus = NULL;
 
                 bus = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, NULL);
+		if (!bus)
+			return FALSE;
+
                 portal = g_dbus_proxy_new_sync (bus,
                                                 0,
                                                 NULL,
@@ -467,23 +479,40 @@ all_headers (GtkListBoxRow *row,
 #ifdef GDK_WINDOWING_WAYLAND
 typedef struct {
         GtkWindow *window;
+        char *handle_str;
         WindowHandleExported callback;
         gpointer user_data;
 } WaylandWindowHandleExportedData;
 
+static void
+free_exported_data (gpointer data)
+{
+        WaylandWindowHandleExportedData *d = data;
+
+        g_free (d->handle_str);
+        g_free (d);
+}
+
+static gboolean
+handle_exported_idle (gpointer user_data)
+{
+        WaylandWindowHandleExportedData *data = user_data;
+
+        data->callback (data->window, data->handle_str, data->user_data);
+        free_exported_data (data);
+
+        return G_SOURCE_REMOVE;
+}
+
 static void
 wayland_window_handle_exported (GdkWindow  *window,
                                 const char *wayland_handle_str,
                                 gpointer    user_data)
 {
         WaylandWindowHandleExportedData *data = user_data;
-        char *handle_str;
 
-        handle_str = g_strdup_printf ("wayland:%s", wayland_handle_str);
-        data->callback (data->window, handle_str, data->user_data);
-        g_free (handle_str);
-
-        g_free (data);
+        data->handle_str = g_strdup_printf ("wayland:%s", wayland_handle_str);
+        g_idle_add (handle_exported_idle, data);
 }
 #endif
 
@@ -492,7 +521,6 @@ window_export_handle (GtkWindow            *window,
                       WindowHandleExported  callback,
                       gpointer              user_data)
 {
-
 #ifdef GDK_WINDOWING_X11
         if (GDK_IS_X11_DISPLAY (gtk_widget_get_display (GTK_WIDGET (window)))) {
                 GdkWindow *gdk_window = gtk_widget_get_window (GTK_WIDGET (window));
@@ -518,8 +546,8 @@ window_export_handle (GtkWindow            *window,
                 if (!gdk_wayland_window_export_handle (gdk_window,
                                                        wayland_window_handle_exported,
                                                        data,
-                                                       g_free)) {
-                        g_free (data);
+                                                       free_exported_data)) {
+                        free_exported_data (data);
                         return FALSE;
                 }
                 else {
@@ -529,6 +557,7 @@ window_export_handle (GtkWindow            *window,
 #endif
 
         g_warning ("Couldn't export handle, unsupported windowing system");
+        callback (window, "", user_data);
 
         return FALSE;
 }
