@@ -24,6 +24,8 @@
 
 #include <libgd/gd.h>
 
+#include <gtk/gtk.h>
+
 #include "gr-window.h"
 #include "gr-details-page.h"
 #include "gr-chef-dialog.h"
@@ -38,6 +40,7 @@
 #include "gr-image-page.h"
 #include "gr-query-editor.h"
 #include "gr-recipe-importer.h"
+#include "gr-recipe-exporter.h"
 #include "gr-about-dialog.h"
 #include "gr-account.h"
 #include "gr-utils.h"
@@ -81,6 +84,7 @@ struct _GrWindow
 
         GObject *file_chooser;
         GrRecipeImporter *importer;
+        GrRecipeExporter *exporter;
 
         GtkWidget *chef_dialog;
         GtkWidget *about_dialog;
@@ -455,6 +459,7 @@ gr_window_finalize (GObject *object)
         g_queue_free_full (self->back_entry_stack, (GDestroyNotify)back_entry_free);
 
         g_clear_object (&self->importer);
+        g_clear_object (&self->exporter);
 
         g_clear_object (&self->undo_recipe);
         if (self->undo_timeout_id) {
@@ -771,9 +776,9 @@ do_import (GrWindow *window,
 }
 
 static void
-file_chooser_response (GtkNativeDialog *self,
-                       int              response_id,
-                       GrWindow        *window)
+file_chooser_import_response (GtkNativeDialog *self,
+                              int              response_id,
+                              GrWindow        *window)
 {
         if (response_id == GTK_RESPONSE_ACCEPT) {
                 g_autoptr(GFile) file = NULL;
@@ -795,58 +800,24 @@ chef_done (GrChefDialog *dialog,
 }
 
 static void
-present_my_chef_dialog (GrWindow *window,
-                        GrChef   *chef)
+present_my_chef_dialog (GrChef   *chef,
+                        gpointer  data)
 {
+        GrWindow *window = data;
+
         window->chef_dialog = (GtkWidget *)gr_chef_dialog_new (chef, FALSE);
         gtk_window_set_title (GTK_WINDOW (window->chef_dialog), _("My Chef Information"));
         g_signal_connect (window->chef_dialog, "done", G_CALLBACK (chef_done), window);
         gr_window_present_dialog (window, GTK_WINDOW (window->chef_dialog));
 }
 
-static void
-got_account_info (const char  *id,
-                  const char  *name,
-                  const char  *image_path,
-                  gpointer     data,
-                  GError      *error)
-{
-        g_autoptr(GrChef) chef = NULL;
-        GrWindow *window = data;
-
-        chef = gr_chef_new ();
-        g_object_set (chef,
-                      "id", id,
-                      "fullname", name,
-                      "image-path", image_path,
-                      NULL);
-
-        present_my_chef_dialog (window, chef);
-}
-
 void
 gr_window_show_my_chef_information (GrWindow *window)
 {
-        GrRecipeStore *store;
-        const char *id;
-        g_autoptr(GrChef) chef = NULL;
-
         if (window->chef_dialog)
                 return;
 
-        store = gr_app_get_recipe_store (GR_APP (g_application_get_default ()));
-
-        id = gr_recipe_store_get_user_key (store);
-
-        if (id != NULL && id[0] != '\0')
-                chef = gr_recipe_store_get_chef (store, id);
-
-        if (chef) {
-                present_my_chef_dialog (window, chef);
-                return;
-        }
-
-        gr_account_get_information (GTK_WINDOW (window), got_account_info, window, NULL);
+        gr_ensure_user_chef (GTK_WINDOW (window), present_my_chef_dialog, window);
 }
 
 void
@@ -868,7 +839,73 @@ gr_window_load_recipe (GrWindow *window,
                                                                        _("Cancel"));
         gtk_native_dialog_set_modal (GTK_NATIVE_DIALOG (window->file_chooser), TRUE);
 
-        g_signal_connect (window->file_chooser, "response", G_CALLBACK (file_chooser_response), window);
+        g_signal_connect (window->file_chooser, "response",
+                          G_CALLBACK (file_chooser_import_response), window);
+
+        gtk_native_dialog_show (GTK_NATIVE_DIALOG (window->file_chooser));
+}
+
+static void
+export_done (GrRecipeExporter *exporter,
+             GFile            *file,
+             GtkWidget        *window)
+{
+        GtkWidget *dialog;
+        g_autofree char *path = NULL;
+
+        path = g_file_get_path (file);
+        dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+                                         GTK_DIALOG_MODAL|GTK_DIALOG_DESTROY_WITH_PARENT,
+                                         GTK_MESSAGE_INFO,
+                                         GTK_BUTTONS_OK,
+                                         _("Recipes have been exported to “%s”"), path);
+        g_signal_connect (dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
+        gtk_widget_show (dialog);
+}
+
+static void
+do_export (GrWindow *window,
+           GFile    *file)
+{
+        if (!window->exporter) {
+                window->exporter = gr_recipe_exporter_new (GTK_WINDOW (window));
+                g_signal_connect (window->exporter, "done", G_CALLBACK (export_done), window);
+        }
+
+        gr_recipe_exporter_export_all (window->exporter, file);
+}
+
+static void
+file_chooser_export_response (GtkNativeDialog *self,
+                              int              response_id,
+                              GrWindow        *window)
+{
+        if (response_id == GTK_RESPONSE_ACCEPT) {
+                g_autoptr(GFile) file = NULL;
+                file = gtk_file_chooser_get_file (GTK_FILE_CHOOSER (self));
+                do_export (window, file);
+        }
+
+        gtk_native_dialog_destroy (self);
+        window->file_chooser = NULL;
+}
+
+void
+gr_window_save_all (GrWindow *window)
+{
+        if (window->file_chooser)
+                return;
+
+        window->file_chooser = (GObject *)gtk_file_chooser_native_new (_("Select a file"),
+                                                                       GTK_WINDOW (window),
+                                                                       GTK_FILE_CHOOSER_ACTION_SAVE,
+                                                                       _("_Export"),
+                                                                       _("_Cancel"));
+        gtk_native_dialog_set_modal (GTK_NATIVE_DIALOG (window->file_chooser), TRUE);
+        gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (window->file_chooser), "all-recipes.gnome-recipes-export");
+
+        g_signal_connect (window->file_chooser, "response",
+                          G_CALLBACK (file_chooser_export_response), window);
 
         gtk_native_dialog_show (GTK_NATIVE_DIALOG (window->file_chooser));
 }
@@ -1133,8 +1170,10 @@ about_response (GtkWidget *dialog,
                 int        response,
                 GrWindow  *window)
 {
-        gtk_widget_destroy (dialog);
-        window->about_dialog = NULL;
+        if (response != GTK_RESPONSE_NONE) {
+                gtk_widget_destroy (dialog);
+                window->about_dialog = NULL;
+        }
 }
 
 void
@@ -1202,7 +1241,7 @@ gr_window_show_news (GrWindow *window)
                 }
 
                 if (ri->news) {
-                        label = gtk_label_new (ri->news);
+                        label = gtk_label_new (ri->news->str);
                         gtk_label_set_xalign (GTK_LABEL (label), 0.0);
                         gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
                         gtk_label_set_max_width_chars (GTK_LABEL (label), 55);
@@ -1214,3 +1253,16 @@ gr_window_show_news (GrWindow *window)
         gtk_widget_show_all (box);
         gr_window_present_dialog (GR_WINDOW (window), dialog);
 }
+
+void
+gr_window_show_report_issue (GrWindow *window)
+{
+        const char *uri = "https://bugzilla.gnome.org/enter_bug.cgi?product=recipes";
+        g_autoptr(GError) error = NULL;
+
+        gtk_header_bar_set_title (GTK_HEADER_BAR (window->header), _("Report Issue"));
+
+        gtk_show_uri_on_window (GTK_WINDOW (window), uri, GDK_CURRENT_TIME, &error);
+        if (error)
+                g_warning ("Unable to show '%s': %s", uri, error->message);
+}
